﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DGL_Löser
{
    class Punkt
    {
        double t, x;
        public double T
        { get { return t; } }
        public double X
        { get { return x; } }
        public Punkt(double t, double x)
        {
            this.t = t;
            this.x = x;
        }
    }

    abstract class Löser
    {
        abstract public List<Punkt> Löse(DGL dgl, double t0, double x0, double t1);
    }
    class EulerVerfahren : Löser
    {
        double deltaT;
        public EulerVerfahren(double deltaT)
        {
            this.deltaT = deltaT;
        }
        public override List<Punkt> Löse(DGL dgl, double t0, double x0, double t1)
        {
            List<Punkt> punkte = new List<Punkt>();
            double t = t0;
            double x = x0;
            punkte.Add(new Punkt(t, x));
            while (t < t1)
            {
                x += dgl.f(t, x) * deltaT;
                t += deltaT;
                punkte.Add(new Punkt(t, x));
            }
            return punkte;
        }
    }

    abstract class DGL
    {
        abstract public double f(double t, double x);
    }
    class meineErsteDGL : DGL
    {
        public override double f(double t, double x)
        {
            return Math.Sin(t) + x*x;
        }
    }
    class meineZweiteDGL : DGL
    {
        public override double f(double t, double x)
        {
            return x * Math.Cos(t);
        }
    }
}
